/**
 * @license
 * Copyright © 2015 Intuilab
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
 *
 * The Software is provided "as is", without warranty of any kind, express or implied, including but not limited to the warranties of merchantability,
 * fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability,
 * whether in an action of contract, tort or otherwise, arising from, out of or in connection with the Software or the use or other dealings in the Software.
 *
 * Except as contained in this notice, the name of Intuilab shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in this Software without prior written authorization from Intuilab.
 */

WhoAmI.prototype = new EventEmitter();        // Here's where the inheritance occurs
WhoAmI.prototype.constructor = WhoAmI;

/**
 * @constructor
 */
function WhoAmI() {
    // Http requests management
    this.httpService = intuiface.get("httpService");
    this.playerService = intuiface.get("playerService");

    this.whoamiServerBasePath = this.playerService.generateIntuiFaceSocialUrl("/whoami");


	var shortLicense = this.playerService.getLicenseId();
	if(shortLicense != null && shortLicense.length > 8)
	{
		shortLicense = shortLicense.substr(0,8);
	}
	
    //Device info
    this.deviceInfo = {
        deviceName : this.playerService.getDeviceName(),
        OS : this.playerService.getPlatform(),
        OSVersion : this.playerService.getOSVersion(),
        applicationName : this.playerService.getApplicationName(),
        completeApplicationName : this.playerService.getCompleteApplicationName(),
        experienceName: this.playerService.getCurrentExperienceName(),
        intuifaceVersion : this.playerService.getIntuiFaceVersion(),
		intuifaceLicense : shortLicense
    };

    //network info
    this.network = {
        ipAddress : "",
        isOnline : false
    };

    //location info
    this.location = {
        country:"",
        city:"",
        latitude:0,
        longitude:0
    };

    this.refreshInfo();

}


WhoAmI.prototype.refreshInfo = function() {
    //find first the IP address, then if success, look for location info.
    this._getNetworkInfo();

};

WhoAmI.prototype._getNetworkInfo = function() {
  //TODO: call social.intuilab.com web services

    var self = this;

    this.httpService.get(this.whoamiServerBasePath + "/ip", {
        "success": function(result) {
            //process your result
            self.network.ipAddress = result;
            self.network.isOnline = true;
            self.emit('networkChanged', [self.network]);

            //IP haa been found, search for Location info
            self._getLocationInfo();
        },
        "error" : function(errorMessage) {
            //TODO: handle error
            //self.emit('Error', [errorMessage]);
            self.network.isOnline = false;
            self.network.ipAddress = "";
        }});

};

WhoAmI.prototype._getLocationInfo = function() {

    var self = this;

    //TODO: call social.intuilab.com web services

    if (this.network.ipAddress != "") {
        var request = this.whoamiServerBasePath + "/location.json";

        this.httpService.get(request, {
            "success": function(result) {
                //process your result
                var obj = result;
                if (typeof obj != 'object') {
                    obj = JSON.parse(result);
                }

                self.location.country = obj.country;
                self.location.city = obj.city;
                self.location.latitude = obj.lat;
                self.location.longitude = obj.lon;
                self.emit('locationChanged', [self.location]);
            },
            "error" : function(errorMessage) {
                //TODO: handle error
                //self.emit('Error', [errorMessage]);
            }});
    }
};



/**
 *
 */
WhoAmI.prototype.dispose = function() {
};



